"""Contains all the data models used in inputs/outputs"""

from .attachment_type import AttachmentType
from .body_upload_workflow_prompt_image_v1_workflows_prompt_image_post import (
    BodyUploadWorkflowPromptImageV1WorkflowsPromptImagePost,
)
from .chain_step import ChainStep
from .chain_step_inputs_type_0 import ChainStepInputsType0
from .chain_step_sensitive_inputs_type_0 import ChainStepSensitiveInputsType0
from .connection_create import ConnectionCreate
from .connection_response import ConnectionResponse
from .connection_status import ConnectionStatus
from .copy_to_clipboard_request import CopyToClipboardRequest
from .copy_to_clipboard_v1_computer_machine_id_copy_to_clipboard_post_response_copy_to_clipboard_v1_computer_machine_id_copy_to_clipboard_post import (
    CopyToClipboardV1ComputerMachineIdCopyToClipboardPostResponseCopyToClipboardV1ComputerMachineIdCopyToClipboardPost,
)
from .display_dimensions import DisplayDimensions
from .file_input import FileInput
from .file_write_request import FileWriteRequest
from .fs_list_v1_computer_machine_id_fs_list_get_response_fs_list_v1_computer_machine_id_fs_list_get import (
    FsListV1ComputerMachineIdFsListGetResponseFsListV1ComputerMachineIdFsListGet,
)
from .fs_read_v1_computer_machine_id_fs_read_get_response_fs_read_v1_computer_machine_id_fs_read_get import (
    FsReadV1ComputerMachineIdFsReadGetResponseFsReadV1ComputerMachineIdFsReadGet,
)
from .fs_write_v1_computer_machine_id_fs_write_post_response_fs_write_v1_computer_machine_id_fs_write_post import (
    FsWriteV1ComputerMachineIdFsWritePostResponseFsWriteV1ComputerMachineIdFsWritePost,
)
from .get_workflow_versions_v1_workflows_workflow_id_versions_get_response_200_item import (
    GetWorkflowVersionsV1WorkflowsWorkflowIdVersionsGetResponse200Item,
)
from .health_check_v1_health_get_response_health_check_v1_health_get import (
    HealthCheckV1HealthGetResponseHealthCheckV1HealthGet,
)
from .http_validation_error import HTTPValidationError
from .keyboard_key_request import KeyboardKeyRequest
from .keyboard_type_request import KeyboardTypeRequest
from .machine_create import MachineCreate
from .machine_create_machine_parameters_type_0 import MachineCreateMachineParametersType0
from .machine_create_machine_sensitive_parameters_type_0 import MachineCreateMachineSensitiveParametersType0
from .machine_pool_assignment import MachinePoolAssignment
from .machine_pool_update import MachinePoolUpdate
from .machine_response import MachineResponse
from .machine_response_machine_parameters_type_0 import MachineResponseMachineParametersType0
from .machine_response_machine_sensitive_parameters_type_0 import MachineResponseMachineSensitiveParametersType0
from .machine_status import MachineStatus
from .machine_update import MachineUpdate
from .machine_update_machine_parameters_type_0 import MachineUpdateMachineParametersType0
from .machine_update_machine_sensitive_parameters_type_0 import MachineUpdateMachineSensitiveParametersType0
from .model_configuration_create import ModelConfigurationCreate
from .model_configuration_create_additional_params_type_0 import ModelConfigurationCreateAdditionalParamsType0
from .model_configuration_response import ModelConfigurationResponse
from .model_configuration_response_additional_params_type_0 import ModelConfigurationResponseAdditionalParamsType0
from .model_configuration_update import ModelConfigurationUpdate
from .model_configuration_update_additional_params_type_0 import ModelConfigurationUpdateAdditionalParamsType0
from .mouse_click_request import MouseClickRequest
from .mouse_drag_request import MouseDragRequest
from .mouse_move_request import MouseMoveRequest
from .mouse_position import MousePosition
from .mouse_scroll_request import MouseScrollRequest
from .paginated_response import PaginatedResponse
from .paginated_response_connection_response import PaginatedResponseConnectionResponse
from .paginated_response_machine_response import PaginatedResponseMachineResponse
from .paginated_response_pool_response import PaginatedResponsePoolResponse
from .paginated_response_run_attachment_response import PaginatedResponseRunAttachmentResponse
from .paginated_response_run_response import PaginatedResponseRunResponse
from .paginated_response_trajectory_response import PaginatedResponseTrajectoryResponse
from .paginated_response_workflow_response import PaginatedResponseWorkflowResponse
from .pool_create import PoolCreate
from .pool_response import PoolResponse
from .pool_update import PoolUpdate
from .pool_with_machines import PoolWithMachines
from .power_shell_exec_request import PowerShellExecRequest
from .power_shell_session_request import PowerShellSessionRequest
from .powershell_exec_v1_computer_machine_id_shell_powershell_exec_post_response_powershell_exec_v1_computer_machine_id_shell_powershell_exec_post import (
    PowershellExecV1ComputerMachineIdShellPowershellExecPostResponsePowershellExecV1ComputerMachineIdShellPowershellExecPost,
)
from .powershell_session_v1_computer_machine_id_shell_powershell_session_post_response_powershell_session_v1_computer_machine_id_shell_powershell_session_post import (
    PowershellSessionV1ComputerMachineIdShellPowershellSessionPostResponsePowershellSessionV1ComputerMachineIdShellPowershellSessionPost,
)
from .request_log_create import RequestLogCreate
from .request_log_response import RequestLogResponse
from .request_log_update import RequestLogUpdate
from .run_attachment_create import RunAttachmentCreate
from .run_attachment_download_url_response import RunAttachmentDownloadUrlResponse
from .run_attachment_response import RunAttachmentResponse
from .run_attachment_update import RunAttachmentUpdate
from .run_bulk_create import RunBulkCreate
from .run_bulk_create_input_values_type_0 import RunBulkCreateInputValuesType0
from .run_bulk_create_response import RunBulkCreateResponse
from .run_bulk_create_sensitive_input_values_type_0 import RunBulkCreateSensitiveInputValuesType0
from .run_completed_event import RunCompletedEvent
from .run_create import RunCreate
from .run_create_input_values_type_0 import RunCreateInputValuesType0
from .run_create_sensitive_input_values_type_0 import RunCreateSensitiveInputValuesType0
from .run_field import RunField
from .run_response import RunResponse
from .run_response_input_values_type_0 import RunResponseInputValuesType0
from .run_response_output_data_type_0 import RunResponseOutputDataType0
from .run_response_run_message_history_type_0_item import RunResponseRunMessageHistoryType0Item
from .run_response_sensitive_input_aliases_type_0 import RunResponseSensitiveInputAliasesType0
from .run_response_usage_metadata_type_0 import RunResponseUsageMetadataType0
from .run_retry import RunRetry
from .run_retry_input_values_type_0 import RunRetryInputValuesType0
from .run_retry_sensitive_input_values_type_0 import RunRetrySensitiveInputValuesType0
from .run_status import RunStatus
from .run_update import RunUpdate
from .run_update_input_values_type_0 import RunUpdateInputValuesType0
from .run_update_output_data_type_0 import RunUpdateOutputDataType0
from .run_update_run_message_history_type_0_item import RunUpdateRunMessageHistoryType0Item
from .run_update_usage_metadata_type_0 import RunUpdateUsageMetadataType0
from .trajectory_create import TrajectoryCreate
from .trajectory_create_dimensions import TrajectoryCreateDimensions
from .trajectory_create_original_input_values_type_0 import TrajectoryCreateOriginalInputValuesType0
from .trajectory_create_trajectory_data_item import TrajectoryCreateTrajectoryDataItem
from .trajectory_response import TrajectoryResponse
from .trajectory_response_dimensions import TrajectoryResponseDimensions
from .trajectory_response_original_input_values_type_0 import TrajectoryResponseOriginalInputValuesType0
from .trajectory_response_trajectory_data_item import TrajectoryResponseTrajectoryDataItem
from .trajectory_update import TrajectoryUpdate
from .trajectory_update_trajectory_data_type_0_item import TrajectoryUpdateTrajectoryDataType0Item
from .usage_aggregate_response import UsageAggregateResponse
from .usage_mode import UsageMode
from .validation_error import ValidationError
from .workflow_chain_create import WorkflowChainCreate
from .workflow_chain_create_shared_inputs_type_0 import WorkflowChainCreateSharedInputsType0
from .workflow_chain_create_shared_sensitive_inputs_type_0 import WorkflowChainCreateSharedSensitiveInputsType0
from .workflow_chain_response import WorkflowChainResponse
from .workflow_create import WorkflowCreate
from .workflow_model_metadata import WorkflowModelMetadata
from .workflow_prompt_image_list_item import WorkflowPromptImageListItem
from .workflow_prompt_image_response import WorkflowPromptImageResponse
from .workflow_prompt_image_signed_url_response import WorkflowPromptImageSignedUrlResponse
from .workflow_response import WorkflowResponse
from .workflow_response_old_versions_type_0_item import WorkflowResponseOldVersionsType0Item
from .workflow_update import WorkflowUpdate

__all__ = (
    "AttachmentType",
    "BodyUploadWorkflowPromptImageV1WorkflowsPromptImagePost",
    "ChainStep",
    "ChainStepInputsType0",
    "ChainStepSensitiveInputsType0",
    "ConnectionCreate",
    "ConnectionResponse",
    "ConnectionStatus",
    "CopyToClipboardRequest",
    "CopyToClipboardV1ComputerMachineIdCopyToClipboardPostResponseCopyToClipboardV1ComputerMachineIdCopyToClipboardPost",
    "DisplayDimensions",
    "FileInput",
    "FileWriteRequest",
    "FsListV1ComputerMachineIdFsListGetResponseFsListV1ComputerMachineIdFsListGet",
    "FsReadV1ComputerMachineIdFsReadGetResponseFsReadV1ComputerMachineIdFsReadGet",
    "FsWriteV1ComputerMachineIdFsWritePostResponseFsWriteV1ComputerMachineIdFsWritePost",
    "GetWorkflowVersionsV1WorkflowsWorkflowIdVersionsGetResponse200Item",
    "HealthCheckV1HealthGetResponseHealthCheckV1HealthGet",
    "HTTPValidationError",
    "KeyboardKeyRequest",
    "KeyboardTypeRequest",
    "MachineCreate",
    "MachineCreateMachineParametersType0",
    "MachineCreateMachineSensitiveParametersType0",
    "MachinePoolAssignment",
    "MachinePoolUpdate",
    "MachineResponse",
    "MachineResponseMachineParametersType0",
    "MachineResponseMachineSensitiveParametersType0",
    "MachineStatus",
    "MachineUpdate",
    "MachineUpdateMachineParametersType0",
    "MachineUpdateMachineSensitiveParametersType0",
    "ModelConfigurationCreate",
    "ModelConfigurationCreateAdditionalParamsType0",
    "ModelConfigurationResponse",
    "ModelConfigurationResponseAdditionalParamsType0",
    "ModelConfigurationUpdate",
    "ModelConfigurationUpdateAdditionalParamsType0",
    "MouseClickRequest",
    "MouseDragRequest",
    "MouseMoveRequest",
    "MousePosition",
    "MouseScrollRequest",
    "PaginatedResponse",
    "PaginatedResponseConnectionResponse",
    "PaginatedResponseMachineResponse",
    "PaginatedResponsePoolResponse",
    "PaginatedResponseRunAttachmentResponse",
    "PaginatedResponseRunResponse",
    "PaginatedResponseTrajectoryResponse",
    "PaginatedResponseWorkflowResponse",
    "PoolCreate",
    "PoolResponse",
    "PoolUpdate",
    "PoolWithMachines",
    "PowerShellExecRequest",
    "PowershellExecV1ComputerMachineIdShellPowershellExecPostResponsePowershellExecV1ComputerMachineIdShellPowershellExecPost",
    "PowerShellSessionRequest",
    "PowershellSessionV1ComputerMachineIdShellPowershellSessionPostResponsePowershellSessionV1ComputerMachineIdShellPowershellSessionPost",
    "RequestLogCreate",
    "RequestLogResponse",
    "RequestLogUpdate",
    "RunAttachmentCreate",
    "RunAttachmentDownloadUrlResponse",
    "RunAttachmentResponse",
    "RunAttachmentUpdate",
    "RunBulkCreate",
    "RunBulkCreateInputValuesType0",
    "RunBulkCreateResponse",
    "RunBulkCreateSensitiveInputValuesType0",
    "RunCompletedEvent",
    "RunCreate",
    "RunCreateInputValuesType0",
    "RunCreateSensitiveInputValuesType0",
    "RunField",
    "RunResponse",
    "RunResponseInputValuesType0",
    "RunResponseOutputDataType0",
    "RunResponseRunMessageHistoryType0Item",
    "RunResponseSensitiveInputAliasesType0",
    "RunResponseUsageMetadataType0",
    "RunRetry",
    "RunRetryInputValuesType0",
    "RunRetrySensitiveInputValuesType0",
    "RunStatus",
    "RunUpdate",
    "RunUpdateInputValuesType0",
    "RunUpdateOutputDataType0",
    "RunUpdateRunMessageHistoryType0Item",
    "RunUpdateUsageMetadataType0",
    "TrajectoryCreate",
    "TrajectoryCreateDimensions",
    "TrajectoryCreateOriginalInputValuesType0",
    "TrajectoryCreateTrajectoryDataItem",
    "TrajectoryResponse",
    "TrajectoryResponseDimensions",
    "TrajectoryResponseOriginalInputValuesType0",
    "TrajectoryResponseTrajectoryDataItem",
    "TrajectoryUpdate",
    "TrajectoryUpdateTrajectoryDataType0Item",
    "UsageAggregateResponse",
    "UsageMode",
    "ValidationError",
    "WorkflowChainCreate",
    "WorkflowChainCreateSharedInputsType0",
    "WorkflowChainCreateSharedSensitiveInputsType0",
    "WorkflowChainResponse",
    "WorkflowCreate",
    "WorkflowModelMetadata",
    "WorkflowPromptImageListItem",
    "WorkflowPromptImageResponse",
    "WorkflowPromptImageSignedUrlResponse",
    "WorkflowResponse",
    "WorkflowResponseOldVersionsType0Item",
    "WorkflowUpdate",
)



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

T = TypeVar("T", bound="WorkflowPromptImageResponse")


@_attrs_define
class WorkflowPromptImageResponse:
    """Response schema for uploaded workflow prompt image

    Attributes:
        supabase_url (str): The stable supabase:// URL to use in workflow prompt HTML. Example: supabase://workflow-
            prompt-images/org_xxx/prompt-assets/image.png
        signed_url (str): A temporary signed URL for immediate display (expires in 1 hour)
        filename (str): The sanitized filename as stored
        content_type (str): The MIME type of the uploaded image
        size_bytes (int): The size of the uploaded file in bytes
    """

    supabase_url: str
    signed_url: str
    filename: str
    content_type: str
    size_bytes: int
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        supabase_url = self.supabase_url

        signed_url = self.signed_url

        filename = self.filename

        content_type = self.content_type

        size_bytes = self.size_bytes

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "supabase_url": supabase_url,
                "signed_url": signed_url,
                "filename": filename,
                "content_type": content_type,
                "size_bytes": size_bytes,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        supabase_url = d.pop("supabase_url")

        signed_url = d.pop("signed_url")

        filename = d.pop("filename")

        content_type = d.pop("content_type")

        size_bytes = d.pop("size_bytes")

        workflow_prompt_image_response = cls(
            supabase_url=supabase_url,
            signed_url=signed_url,
            filename=filename,
            content_type=content_type,
            size_bytes=size_bytes,
        )

        workflow_prompt_image_response.additional_properties = d
        return workflow_prompt_image_response

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, cast
from uuid import UUID

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.model_configuration_response_additional_params_type_0 import (
        ModelConfigurationResponseAdditionalParamsType0,
    )


T = TypeVar("T", bound="ModelConfigurationResponse")


@_attrs_define
class ModelConfigurationResponse:
    """API response schema for model configurations.

    Attributes:
        name (str):
        provider (str): LangChain provider name (e.g. 'anthropic', 'openai').
        model (str): Provider model identifier (e.g. 'claude-sonnet-4-5-20250929').
        id (UUID):
        is_system_default (bool):
        created_at (datetime.datetime):
        updated_at (datetime.datetime):
        description (None | str | Unset):
        temperature (float | None | Unset):
        max_tokens (int | None | Unset):
        timeout_seconds (float | None | Unset):
        max_retries (int | None | Unset):
        additional_params (ModelConfigurationResponseAdditionalParamsType0 | None | Unset): Provider-specific kwargs
            passed through to LangChain.
        is_computer_use_model (bool | Unset): True if this model has native computer use capabilities. If True, can be
            used for main agent, focused actions, and fallbacks for those agents. Default: False.
        organization_id (None | str | Unset):
        api_key_alias (None | str | Unset): Basis Theory token id (alias) used to resolve api_key at runtime.
    """

    name: str
    provider: str
    model: str
    id: UUID
    is_system_default: bool
    created_at: datetime.datetime
    updated_at: datetime.datetime
    description: None | str | Unset = UNSET
    temperature: float | None | Unset = UNSET
    max_tokens: int | None | Unset = UNSET
    timeout_seconds: float | None | Unset = UNSET
    max_retries: int | None | Unset = UNSET
    additional_params: ModelConfigurationResponseAdditionalParamsType0 | None | Unset = UNSET
    is_computer_use_model: bool | Unset = False
    organization_id: None | str | Unset = UNSET
    api_key_alias: None | str | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        from ..models.model_configuration_response_additional_params_type_0 import (
            ModelConfigurationResponseAdditionalParamsType0,
        )

        name = self.name

        provider = self.provider

        model = self.model

        id = str(self.id)

        is_system_default = self.is_system_default

        created_at = self.created_at.isoformat()

        updated_at = self.updated_at.isoformat()

        description: None | str | Unset
        if isinstance(self.description, Unset):
            description = UNSET
        else:
            description = self.description

        temperature: float | None | Unset
        if isinstance(self.temperature, Unset):
            temperature = UNSET
        else:
            temperature = self.temperature

        max_tokens: int | None | Unset
        if isinstance(self.max_tokens, Unset):
            max_tokens = UNSET
        else:
            max_tokens = self.max_tokens

        timeout_seconds: float | None | Unset
        if isinstance(self.timeout_seconds, Unset):
            timeout_seconds = UNSET
        else:
            timeout_seconds = self.timeout_seconds

        max_retries: int | None | Unset
        if isinstance(self.max_retries, Unset):
            max_retries = UNSET
        else:
            max_retries = self.max_retries

        additional_params: dict[str, Any] | None | Unset
        if isinstance(self.additional_params, Unset):
            additional_params = UNSET
        elif isinstance(self.additional_params, ModelConfigurationResponseAdditionalParamsType0):
            additional_params = self.additional_params.to_dict()
        else:
            additional_params = self.additional_params

        is_computer_use_model = self.is_computer_use_model

        organization_id: None | str | Unset
        if isinstance(self.organization_id, Unset):
            organization_id = UNSET
        else:
            organization_id = self.organization_id

        api_key_alias: None | str | Unset
        if isinstance(self.api_key_alias, Unset):
            api_key_alias = UNSET
        else:
            api_key_alias = self.api_key_alias

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "name": name,
                "provider": provider,
                "model": model,
                "id": id,
                "is_system_default": is_system_default,
                "created_at": created_at,
                "updated_at": updated_at,
            }
        )
        if description is not UNSET:
            field_dict["description"] = description
        if temperature is not UNSET:
            field_dict["temperature"] = temperature
        if max_tokens is not UNSET:
            field_dict["max_tokens"] = max_tokens
        if timeout_seconds is not UNSET:
            field_dict["timeout_seconds"] = timeout_seconds
        if max_retries is not UNSET:
            field_dict["max_retries"] = max_retries
        if additional_params is not UNSET:
            field_dict["additional_params"] = additional_params
        if is_computer_use_model is not UNSET:
            field_dict["is_computer_use_model"] = is_computer_use_model
        if organization_id is not UNSET:
            field_dict["organization_id"] = organization_id
        if api_key_alias is not UNSET:
            field_dict["api_key_alias"] = api_key_alias

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.model_configuration_response_additional_params_type_0 import (
            ModelConfigurationResponseAdditionalParamsType0,
        )

        d = dict(src_dict)
        name = d.pop("name")

        provider = d.pop("provider")

        model = d.pop("model")

        id = UUID(d.pop("id"))

        is_system_default = d.pop("is_system_default")

        created_at = isoparse(d.pop("created_at"))

        updated_at = isoparse(d.pop("updated_at"))

        def _parse_description(data: object) -> None | str | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(None | str | Unset, data)

        description = _parse_description(d.pop("description", UNSET))

        def _parse_temperature(data: object) -> float | None | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(float | None | Unset, data)

        temperature = _parse_temperature(d.pop("temperature", UNSET))

        def _parse_max_tokens(data: object) -> int | None | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(int | None | Unset, data)

        max_tokens = _parse_max_tokens(d.pop("max_tokens", UNSET))

        def _parse_timeout_seconds(data: object) -> float | None | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(float | None | Unset, data)

        timeout_seconds = _parse_timeout_seconds(d.pop("timeout_seconds", UNSET))

        def _parse_max_retries(data: object) -> int | None | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(int | None | Unset, data)

        max_retries = _parse_max_retries(d.pop("max_retries", UNSET))

        def _parse_additional_params(data: object) -> ModelConfigurationResponseAdditionalParamsType0 | None | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                additional_params_type_0 = ModelConfigurationResponseAdditionalParamsType0.from_dict(data)

                return additional_params_type_0
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            return cast(ModelConfigurationResponseAdditionalParamsType0 | None | Unset, data)

        additional_params = _parse_additional_params(d.pop("additional_params", UNSET))

        is_computer_use_model = d.pop("is_computer_use_model", UNSET)

        def _parse_organization_id(data: object) -> None | str | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(None | str | Unset, data)

        organization_id = _parse_organization_id(d.pop("organization_id", UNSET))

        def _parse_api_key_alias(data: object) -> None | str | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(None | str | Unset, data)

        api_key_alias = _parse_api_key_alias(d.pop("api_key_alias", UNSET))

        model_configuration_response = cls(
            name=name,
            provider=provider,
            model=model,
            id=id,
            is_system_default=is_system_default,
            created_at=created_at,
            updated_at=updated_at,
            description=description,
            temperature=temperature,
            max_tokens=max_tokens,
            timeout_seconds=timeout_seconds,
            max_retries=max_retries,
            additional_params=additional_params,
            is_computer_use_model=is_computer_use_model,
            organization_id=organization_id,
            api_key_alias=api_key_alias,
        )

        model_configuration_response.additional_properties = d
        return model_configuration_response

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

import datetime
from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..models.usage_mode import UsageMode

T = TypeVar("T", bound="UsageAggregateResponse")


@_attrs_define
class UsageAggregateResponse:
    """Response schema for usage aggregation.

    Attributes:
        total_agentic_steps (int):
        total_cached_steps (int):
        period_start (datetime.datetime):
        period_end (datetime.datetime):
        mode (UsageMode): Mode for counting usage steps.
        runs_counted (int):
    """

    total_agentic_steps: int
    total_cached_steps: int
    period_start: datetime.datetime
    period_end: datetime.datetime
    mode: UsageMode
    runs_counted: int
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        total_agentic_steps = self.total_agentic_steps

        total_cached_steps = self.total_cached_steps

        period_start = self.period_start.isoformat()

        period_end = self.period_end.isoformat()

        mode = self.mode.value

        runs_counted = self.runs_counted

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "total_agentic_steps": total_agentic_steps,
                "total_cached_steps": total_cached_steps,
                "period_start": period_start,
                "period_end": period_end,
                "mode": mode,
                "runs_counted": runs_counted,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        total_agentic_steps = d.pop("total_agentic_steps")

        total_cached_steps = d.pop("total_cached_steps")

        period_start = isoparse(d.pop("period_start"))

        period_end = isoparse(d.pop("period_end"))

        mode = UsageMode(d.pop("mode"))

        runs_counted = d.pop("runs_counted")

        usage_aggregate_response = cls(
            total_agentic_steps=total_agentic_steps,
            total_cached_steps=total_cached_steps,
            period_start=period_start,
            period_end=period_end,
            mode=mode,
            runs_counted=runs_counted,
        )

        usage_aggregate_response.additional_properties = d
        return usage_aggregate_response

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, cast
from uuid import UUID

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.trajectory_create_dimensions import TrajectoryCreateDimensions
    from ..models.trajectory_create_original_input_values_type_0 import TrajectoryCreateOriginalInputValuesType0
    from ..models.trajectory_create_trajectory_data_item import TrajectoryCreateTrajectoryDataItem


T = TypeVar("T", bound="TrajectoryCreate")


@_attrs_define
class TrajectoryCreate:
    """Schema for creating a trajectory

    Attributes:
        workflow_id (UUID):
        trajectory_data (list[TrajectoryCreateTrajectoryDataItem]):
        dimensions (TrajectoryCreateDimensions): Display dimensions when trajectory was recorded
        name (None | str | Unset):
        description (None | str | Unset):
        original_input_values (None | TrajectoryCreateOriginalInputValuesType0 | Unset): Original input values used when
            trajectory was created
        is_approved (bool | Unset): Whether this trajectory is approved for use Default: False.
    """

    workflow_id: UUID
    trajectory_data: list[TrajectoryCreateTrajectoryDataItem]
    dimensions: TrajectoryCreateDimensions
    name: None | str | Unset = UNSET
    description: None | str | Unset = UNSET
    original_input_values: None | TrajectoryCreateOriginalInputValuesType0 | Unset = UNSET
    is_approved: bool | Unset = False
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        from ..models.trajectory_create_original_input_values_type_0 import TrajectoryCreateOriginalInputValuesType0

        workflow_id = str(self.workflow_id)

        trajectory_data = []
        for trajectory_data_item_data in self.trajectory_data:
            trajectory_data_item = trajectory_data_item_data.to_dict()
            trajectory_data.append(trajectory_data_item)

        dimensions = self.dimensions.to_dict()

        name: None | str | Unset
        if isinstance(self.name, Unset):
            name = UNSET
        else:
            name = self.name

        description: None | str | Unset
        if isinstance(self.description, Unset):
            description = UNSET
        else:
            description = self.description

        original_input_values: dict[str, Any] | None | Unset
        if isinstance(self.original_input_values, Unset):
            original_input_values = UNSET
        elif isinstance(self.original_input_values, TrajectoryCreateOriginalInputValuesType0):
            original_input_values = self.original_input_values.to_dict()
        else:
            original_input_values = self.original_input_values

        is_approved = self.is_approved

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "workflow_id": workflow_id,
                "trajectory_data": trajectory_data,
                "dimensions": dimensions,
            }
        )
        if name is not UNSET:
            field_dict["name"] = name
        if description is not UNSET:
            field_dict["description"] = description
        if original_input_values is not UNSET:
            field_dict["original_input_values"] = original_input_values
        if is_approved is not UNSET:
            field_dict["is_approved"] = is_approved

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.trajectory_create_dimensions import TrajectoryCreateDimensions
        from ..models.trajectory_create_original_input_values_type_0 import TrajectoryCreateOriginalInputValuesType0
        from ..models.trajectory_create_trajectory_data_item import TrajectoryCreateTrajectoryDataItem

        d = dict(src_dict)
        workflow_id = UUID(d.pop("workflow_id"))

        trajectory_data = []
        _trajectory_data = d.pop("trajectory_data")
        for trajectory_data_item_data in _trajectory_data:
            trajectory_data_item = TrajectoryCreateTrajectoryDataItem.from_dict(trajectory_data_item_data)

            trajectory_data.append(trajectory_data_item)

        dimensions = TrajectoryCreateDimensions.from_dict(d.pop("dimensions"))

        def _parse_name(data: object) -> None | str | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(None | str | Unset, data)

        name = _parse_name(d.pop("name", UNSET))

        def _parse_description(data: object) -> None | str | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(None | str | Unset, data)

        description = _parse_description(d.pop("description", UNSET))

        def _parse_original_input_values(data: object) -> None | TrajectoryCreateOriginalInputValuesType0 | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                original_input_values_type_0 = TrajectoryCreateOriginalInputValuesType0.from_dict(data)

                return original_input_values_type_0
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            return cast(None | TrajectoryCreateOriginalInputValuesType0 | Unset, data)

        original_input_values = _parse_original_input_values(d.pop("original_input_values", UNSET))

        is_approved = d.pop("is_approved", UNSET)

        trajectory_create = cls(
            workflow_id=workflow_id,
            trajectory_data=trajectory_data,
            dimensions=dimensions,
            name=name,
            description=description,
            original_input_values=original_input_values,
            is_approved=is_approved,
        )

        trajectory_create.additional_properties = d
        return trajectory_create

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, cast
from uuid import UUID

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.workflow_model_metadata import WorkflowModelMetadata
    from ..models.workflow_response_old_versions_type_0_item import WorkflowResponseOldVersionsType0Item


T = TypeVar("T", bound="WorkflowResponse")


@_attrs_define
class WorkflowResponse:
    """Workflow response schema

    Attributes:
        main_prompt (str):
        id (UUID):
        created_at (datetime.datetime):
        updated_at (datetime.datetime):
        name (None | str | Unset):
        output_schema (None | str | Unset): JSON schema for output data transformation
        includes_file_exports (bool | Unset): Enable AI-based file export detection Default: False.
        is_webhooks_enabled (bool | Unset): Send webhook on run completion Default: False.
        model_metadata (None | Unset | WorkflowModelMetadata): Optional workflow-level model configuration metadata
            (main agent + fallbacks).
        user_id (None | Unset | UUID):
        organization_id (None | str | Unset):
        includes_input_variables (bool | Unset):  Default: False.
        old_versions (list[WorkflowResponseOldVersionsType0Item] | None | Unset):
    """

    main_prompt: str
    id: UUID
    created_at: datetime.datetime
    updated_at: datetime.datetime
    name: None | str | Unset = UNSET
    output_schema: None | str | Unset = UNSET
    includes_file_exports: bool | Unset = False
    is_webhooks_enabled: bool | Unset = False
    model_metadata: None | Unset | WorkflowModelMetadata = UNSET
    user_id: None | Unset | UUID = UNSET
    organization_id: None | str | Unset = UNSET
    includes_input_variables: bool | Unset = False
    old_versions: list[WorkflowResponseOldVersionsType0Item] | None | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        from ..models.workflow_model_metadata import WorkflowModelMetadata

        main_prompt = self.main_prompt

        id = str(self.id)

        created_at = self.created_at.isoformat()

        updated_at = self.updated_at.isoformat()

        name: None | str | Unset
        if isinstance(self.name, Unset):
            name = UNSET
        else:
            name = self.name

        output_schema: None | str | Unset
        if isinstance(self.output_schema, Unset):
            output_schema = UNSET
        else:
            output_schema = self.output_schema

        includes_file_exports = self.includes_file_exports

        is_webhooks_enabled = self.is_webhooks_enabled

        model_metadata: dict[str, Any] | None | Unset
        if isinstance(self.model_metadata, Unset):
            model_metadata = UNSET
        elif isinstance(self.model_metadata, WorkflowModelMetadata):
            model_metadata = self.model_metadata.to_dict()
        else:
            model_metadata = self.model_metadata

        user_id: None | str | Unset
        if isinstance(self.user_id, Unset):
            user_id = UNSET
        elif isinstance(self.user_id, UUID):
            user_id = str(self.user_id)
        else:
            user_id = self.user_id

        organization_id: None | str | Unset
        if isinstance(self.organization_id, Unset):
            organization_id = UNSET
        else:
            organization_id = self.organization_id

        includes_input_variables = self.includes_input_variables

        old_versions: list[dict[str, Any]] | None | Unset
        if isinstance(self.old_versions, Unset):
            old_versions = UNSET
        elif isinstance(self.old_versions, list):
            old_versions = []
            for old_versions_type_0_item_data in self.old_versions:
                old_versions_type_0_item = old_versions_type_0_item_data.to_dict()
                old_versions.append(old_versions_type_0_item)

        else:
            old_versions = self.old_versions

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "main_prompt": main_prompt,
                "id": id,
                "created_at": created_at,
                "updated_at": updated_at,
            }
        )
        if name is not UNSET:
            field_dict["name"] = name
        if output_schema is not UNSET:
            field_dict["output_schema"] = output_schema
        if includes_file_exports is not UNSET:
            field_dict["includes_file_exports"] = includes_file_exports
        if is_webhooks_enabled is not UNSET:
            field_dict["is_webhooks_enabled"] = is_webhooks_enabled
        if model_metadata is not UNSET:
            field_dict["model_metadata"] = model_metadata
        if user_id is not UNSET:
            field_dict["user_id"] = user_id
        if organization_id is not UNSET:
            field_dict["organization_id"] = organization_id
        if includes_input_variables is not UNSET:
            field_dict["includes_input_variables"] = includes_input_variables
        if old_versions is not UNSET:
            field_dict["old_versions"] = old_versions

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.workflow_model_metadata import WorkflowModelMetadata
        from ..models.workflow_response_old_versions_type_0_item import WorkflowResponseOldVersionsType0Item

        d = dict(src_dict)
        main_prompt = d.pop("main_prompt")

        id = UUID(d.pop("id"))

        created_at = isoparse(d.pop("created_at"))

        updated_at = isoparse(d.pop("updated_at"))

        def _parse_name(data: object) -> None | str | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(None | str | Unset, data)

        name = _parse_name(d.pop("name", UNSET))

        def _parse_output_schema(data: object) -> None | str | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(None | str | Unset, data)

        output_schema = _parse_output_schema(d.pop("output_schema", UNSET))

        includes_file_exports = d.pop("includes_file_exports", UNSET)

        is_webhooks_enabled = d.pop("is_webhooks_enabled", UNSET)

        def _parse_model_metadata(data: object) -> None | Unset | WorkflowModelMetadata:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                model_metadata_type_0 = WorkflowModelMetadata.from_dict(data)

                return model_metadata_type_0
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            return cast(None | Unset | WorkflowModelMetadata, data)

        model_metadata = _parse_model_metadata(d.pop("model_metadata", UNSET))

        def _parse_user_id(data: object) -> None | Unset | UUID:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                user_id_type_0 = UUID(data)

                return user_id_type_0
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            return cast(None | Unset | UUID, data)

        user_id = _parse_user_id(d.pop("user_id", UNSET))

        def _parse_organization_id(data: object) -> None | str | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(None | str | Unset, data)

        organization_id = _parse_organization_id(d.pop("organization_id", UNSET))

        includes_input_variables = d.pop("includes_input_variables", UNSET)

        def _parse_old_versions(data: object) -> list[WorkflowResponseOldVersionsType0Item] | None | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                old_versions_type_0 = []
                _old_versions_type_0 = data
                for old_versions_type_0_item_data in _old_versions_type_0:
                    old_versions_type_0_item = WorkflowResponseOldVersionsType0Item.from_dict(
                        old_versions_type_0_item_data
                    )

                    old_versions_type_0.append(old_versions_type_0_item)

                return old_versions_type_0
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            return cast(list[WorkflowResponseOldVersionsType0Item] | None | Unset, data)

        old_versions = _parse_old_versions(d.pop("old_versions", UNSET))

        workflow_response = cls(
            main_prompt=main_prompt,
            id=id,
            created_at=created_at,
            updated_at=updated_at,
            name=name,
            output_schema=output_schema,
            includes_file_exports=includes_file_exports,
            is_webhooks_enabled=is_webhooks_enabled,
            model_metadata=model_metadata,
            user_id=user_id,
            organization_id=organization_id,
            includes_input_variables=includes_input_variables,
            old_versions=old_versions,
        )

        workflow_response.additional_properties = d
        return workflow_response

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.model_configuration_update_additional_params_type_0 import (
        ModelConfigurationUpdateAdditionalParamsType0,
    )


T = TypeVar("T", bound="ModelConfigurationUpdate")


@_attrs_define
class ModelConfigurationUpdate:
    """Update a model configuration (organization-owned only).

    Attributes:
        name (None | str | Unset):
        description (None | str | Unset):
        provider (None | str | Unset):
        model (None | str | Unset):
        api_key (None | str | Unset): Raw API key; if provided, replaces the stored alias.
        clear_api_key (bool | None | Unset): If true, clears any stored api_key_alias (reverts to Cyberdesk-provided key
            if supported).
        temperature (float | None | Unset):
        max_tokens (int | None | Unset):
        timeout_seconds (float | None | Unset):
        max_retries (int | None | Unset):
        additional_params (ModelConfigurationUpdateAdditionalParamsType0 | None | Unset):
        is_computer_use_model (bool | None | Unset):
    """

    name: None | str | Unset = UNSET
    description: None | str | Unset = UNSET
    provider: None | str | Unset = UNSET
    model: None | str | Unset = UNSET
    api_key: None | str | Unset = UNSET
    clear_api_key: bool | None | Unset = UNSET
    temperature: float | None | Unset = UNSET
    max_tokens: int | None | Unset = UNSET
    timeout_seconds: float | None | Unset = UNSET
    max_retries: int | None | Unset = UNSET
    additional_params: ModelConfigurationUpdateAdditionalParamsType0 | None | Unset = UNSET
    is_computer_use_model: bool | None | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        from ..models.model_configuration_update_additional_params_type_0 import (
            ModelConfigurationUpdateAdditionalParamsType0,
        )

        name: None | str | Unset
        if isinstance(self.name, Unset):
            name = UNSET
        else:
            name = self.name

        description: None | str | Unset
        if isinstance(self.description, Unset):
            description = UNSET
        else:
            description = self.description

        provider: None | str | Unset
        if isinstance(self.provider, Unset):
            provider = UNSET
        else:
            provider = self.provider

        model: None | str | Unset
        if isinstance(self.model, Unset):
            model = UNSET
        else:
            model = self.model

        api_key: None | str | Unset
        if isinstance(self.api_key, Unset):
            api_key = UNSET
        else:
            api_key = self.api_key

        clear_api_key: bool | None | Unset
        if isinstance(self.clear_api_key, Unset):
            clear_api_key = UNSET
        else:
            clear_api_key = self.clear_api_key

        temperature: float | None | Unset
        if isinstance(self.temperature, Unset):
            temperature = UNSET
        else:
            temperature = self.temperature

        max_tokens: int | None | Unset
        if isinstance(self.max_tokens, Unset):
            max_tokens = UNSET
        else:
            max_tokens = self.max_tokens

        timeout_seconds: float | None | Unset
        if isinstance(self.timeout_seconds, Unset):
            timeout_seconds = UNSET
        else:
            timeout_seconds = self.timeout_seconds

        max_retries: int | None | Unset
        if isinstance(self.max_retries, Unset):
            max_retries = UNSET
        else:
            max_retries = self.max_retries

        additional_params: dict[str, Any] | None | Unset
        if isinstance(self.additional_params, Unset):
            additional_params = UNSET
        elif isinstance(self.additional_params, ModelConfigurationUpdateAdditionalParamsType0):
            additional_params = self.additional_params.to_dict()
        else:
            additional_params = self.additional_params

        is_computer_use_model: bool | None | Unset
        if isinstance(self.is_computer_use_model, Unset):
            is_computer_use_model = UNSET
        else:
            is_computer_use_model = self.is_computer_use_model

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if name is not UNSET:
            field_dict["name"] = name
        if description is not UNSET:
            field_dict["description"] = description
        if provider is not UNSET:
            field_dict["provider"] = provider
        if model is not UNSET:
            field_dict["model"] = model
        if api_key is not UNSET:
            field_dict["api_key"] = api_key
        if clear_api_key is not UNSET:
            field_dict["clear_api_key"] = clear_api_key
        if temperature is not UNSET:
            field_dict["temperature"] = temperature
        if max_tokens is not UNSET:
            field_dict["max_tokens"] = max_tokens
        if timeout_seconds is not UNSET:
            field_dict["timeout_seconds"] = timeout_seconds
        if max_retries is not UNSET:
            field_dict["max_retries"] = max_retries
        if additional_params is not UNSET:
            field_dict["additional_params"] = additional_params
        if is_computer_use_model is not UNSET:
            field_dict["is_computer_use_model"] = is_computer_use_model

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.model_configuration_update_additional_params_type_0 import (
            ModelConfigurationUpdateAdditionalParamsType0,
        )

        d = dict(src_dict)

        def _parse_name(data: object) -> None | str | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(None | str | Unset, data)

        name = _parse_name(d.pop("name", UNSET))

        def _parse_description(data: object) -> None | str | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(None | str | Unset, data)

        description = _parse_description(d.pop("description", UNSET))

        def _parse_provider(data: object) -> None | str | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(None | str | Unset, data)

        provider = _parse_provider(d.pop("provider", UNSET))

        def _parse_model(data: object) -> None | str | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(None | str | Unset, data)

        model = _parse_model(d.pop("model", UNSET))

        def _parse_api_key(data: object) -> None | str | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(None | str | Unset, data)

        api_key = _parse_api_key(d.pop("api_key", UNSET))

        def _parse_clear_api_key(data: object) -> bool | None | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(bool | None | Unset, data)

        clear_api_key = _parse_clear_api_key(d.pop("clear_api_key", UNSET))

        def _parse_temperature(data: object) -> float | None | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(float | None | Unset, data)

        temperature = _parse_temperature(d.pop("temperature", UNSET))

        def _parse_max_tokens(data: object) -> int | None | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(int | None | Unset, data)

        max_tokens = _parse_max_tokens(d.pop("max_tokens", UNSET))

        def _parse_timeout_seconds(data: object) -> float | None | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(float | None | Unset, data)

        timeout_seconds = _parse_timeout_seconds(d.pop("timeout_seconds", UNSET))

        def _parse_max_retries(data: object) -> int | None | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(int | None | Unset, data)

        max_retries = _parse_max_retries(d.pop("max_retries", UNSET))

        def _parse_additional_params(data: object) -> ModelConfigurationUpdateAdditionalParamsType0 | None | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                additional_params_type_0 = ModelConfigurationUpdateAdditionalParamsType0.from_dict(data)

                return additional_params_type_0
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            return cast(ModelConfigurationUpdateAdditionalParamsType0 | None | Unset, data)

        additional_params = _parse_additional_params(d.pop("additional_params", UNSET))

        def _parse_is_computer_use_model(data: object) -> bool | None | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(bool | None | Unset, data)

        is_computer_use_model = _parse_is_computer_use_model(d.pop("is_computer_use_model", UNSET))

        model_configuration_update = cls(
            name=name,
            description=description,
            provider=provider,
            model=model,
            api_key=api_key,
            clear_api_key=clear_api_key,
            temperature=temperature,
            max_tokens=max_tokens,
            timeout_seconds=timeout_seconds,
            max_retries=max_retries,
            additional_params=additional_params,
            is_computer_use_model=is_computer_use_model,
        )

        model_configuration_update.additional_properties = d
        return model_configuration_update

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



"""Cyberdesk Python SDK."""

from .client import (
    CyberdeskClient,
    RetryConfig,
    MachineCreate,
    MachineUpdate,
    MachineResponse,
    MachineStatus,
    WorkflowCreate,
    WorkflowUpdate,
    WorkflowResponse,
    RunCreate,
    RunUpdate,
    RunResponse,
    RunStatus,
    FileInput,
    ConnectionCreate,
    ConnectionResponse,
    ConnectionStatus,
    TrajectoryCreate,
    TrajectoryUpdate,
    TrajectoryResponse,
    RunAttachmentCreate,
    RunAttachmentUpdate,
    RunAttachmentResponse,
    RunAttachmentDownloadUrlResponse,
    AttachmentType,
    ModelConfigurationCreate,
    ModelConfigurationUpdate,
    ModelConfigurationResponse,
    UsageAggregateResponse,
    UsageMode,
)

from .types import (
    MessageContentBlock,
    ChatMessage,
    RunMessageHistory,
)

__version__ = "2.2.16"

__all__ = [
    "CyberdeskClient",
    "RetryConfig",
    "MachineCreate",
    "MachineUpdate",
    "MachineResponse",
    "MachineStatus",
    "WorkflowCreate",
    "WorkflowUpdate",
    "WorkflowResponse",
    "RunCreate",
    "RunUpdate",
    "RunResponse",
    "RunStatus",
    "FileInput",
    "ConnectionCreate",
    "ConnectionResponse",
    "ConnectionStatus",
    "TrajectoryCreate",
    "TrajectoryUpdate",
    "TrajectoryResponse",
    "RunAttachmentCreate",
    "RunAttachmentUpdate",
    "RunAttachmentResponse",
    "RunAttachmentDownloadUrlResponse",
    "AttachmentType",
    "ModelConfigurationCreate",
    "ModelConfigurationUpdate",
    "ModelConfigurationResponse",
    "UsageAggregateResponse",
    "UsageMode",
    "MessageContentBlock",
    "ChatMessage",
    "RunMessageHistory",
] 


from http import HTTPStatus
from typing import Any, cast
from urllib.parse import quote
from uuid import UUID

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.http_validation_error import HTTPValidationError
from ...types import UNSET, Response, Unset


def _get_kwargs(
    workflow_id: UUID,
    *,
    idempotency_key: str | Unset = UNSET,
) -> dict[str, Any]:
    headers: dict[str, Any] = {}
    if not isinstance(idempotency_key, Unset):
        headers["Idempotency-Key"] = idempotency_key

    _kwargs: dict[str, Any] = {
        "method": "delete",
        "url": "/v1/workflows/{workflow_id}".format(
            workflow_id=quote(str(workflow_id), safe=""),
        ),
    }

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(
    *, client: AuthenticatedClient | Client, response: httpx.Response
) -> Any | HTTPValidationError | None:
    if response.status_code == 204:
        response_204 = cast(Any, None)
        return response_204

    if response.status_code == 422:
        response_422 = HTTPValidationError.from_dict(response.json())

        return response_422

    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: AuthenticatedClient | Client, response: httpx.Response
) -> Response[Any | HTTPValidationError]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    workflow_id: UUID,
    *,
    client: AuthenticatedClient,
    idempotency_key: str | Unset = UNSET,
) -> Response[Any | HTTPValidationError]:
    """Delete Workflow

     Delete a workflow.

    This will also delete all associated runs and trajectories.
    The workflow must belong to the authenticated organization.

    Args:
        workflow_id (UUID):
        idempotency_key (str | Unset):  Example: 550e8400-e29b-41d4-a716-446655440000.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any | HTTPValidationError]
    """

    kwargs = _get_kwargs(
        workflow_id=workflow_id,
        idempotency_key=idempotency_key,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    workflow_id: UUID,
    *,
    client: AuthenticatedClient,
    idempotency_key: str | Unset = UNSET,
) -> Any | HTTPValidationError | None:
    """Delete Workflow

     Delete a workflow.

    This will also delete all associated runs and trajectories.
    The workflow must belong to the authenticated organization.

    Args:
        workflow_id (UUID):
        idempotency_key (str | Unset):  Example: 550e8400-e29b-41d4-a716-446655440000.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Any | HTTPValidationError
    """

    return sync_detailed(
        workflow_id=workflow_id,
        client=client,
        idempotency_key=idempotency_key,
    ).parsed


async def asyncio_detailed(
    workflow_id: UUID,
    *,
    client: AuthenticatedClient,
    idempotency_key: str | Unset = UNSET,
) -> Response[Any | HTTPValidationError]:
    """Delete Workflow

     Delete a workflow.

    This will also delete all associated runs and trajectories.
    The workflow must belong to the authenticated organization.

    Args:
        workflow_id (UUID):
        idempotency_key (str | Unset):  Example: 550e8400-e29b-41d4-a716-446655440000.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any | HTTPValidationError]
    """

    kwargs = _get_kwargs(
        workflow_id=workflow_id,
        idempotency_key=idempotency_key,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    workflow_id: UUID,
    *,
    client: AuthenticatedClient,
    idempotency_key: str | Unset = UNSET,
) -> Any | HTTPValidationError | None:
    """Delete Workflow

     Delete a workflow.

    This will also delete all associated runs and trajectories.
    The workflow must belong to the authenticated organization.

    Args:
        workflow_id (UUID):
        idempotency_key (str | Unset):  Example: 550e8400-e29b-41d4-a716-446655440000.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Any | HTTPValidationError
    """

    return (
        await asyncio_detailed(
            workflow_id=workflow_id,
            client=client,
            idempotency_key=idempotency_key,
        )
    ).parsed



from enum import Enum


class RunField(str, Enum):
    ENDED_AT = "ended_at"
    ERROR = "error"
    INPUT_ATTACHMENT_IDS = "input_attachment_ids"
    INPUT_VALUES = "input_values"
    MACHINE_ID = "machine_id"
    ORGANIZATION_ID = "organization_id"
    OUTPUT_ATTACHMENT_IDS = "output_attachment_ids"
    OUTPUT_DATA = "output_data"
    POOL_IDS = "pool_ids"
    RELEASE_SESSION_AFTER = "release_session_after"
    RUN_MESSAGE_HISTORY = "run_message_history"
    SENSITIVE_INPUT_ALIASES = "sensitive_input_aliases"
    SESSION_ALIAS = "session_alias"
    SESSION_ID = "session_id"
    STARTED_AT = "started_at"
    USAGE_METADATA = "usage_metadata"
    USER_ID = "user_id"

    def __str__(self) -> str:
        return str(self.value)



from __future__ import annotations

import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..models.run_status import RunStatus
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.run_update_input_values_type_0 import RunUpdateInputValuesType0
    from ..models.run_update_output_data_type_0 import RunUpdateOutputDataType0
    from ..models.run_update_run_message_history_type_0_item import RunUpdateRunMessageHistoryType0Item
    from ..models.run_update_usage_metadata_type_0 import RunUpdateUsageMetadataType0


T = TypeVar("T", bound="RunUpdate")


@_attrs_define
class RunUpdate:
    """Schema for updating a run

    Attributes:
        status (None | RunStatus | Unset):
        error (list[str] | None | Unset):
        output_data (None | RunUpdateOutputDataType0 | Unset):
        output_attachment_ids (list[str] | None | Unset):
        run_message_history (list[RunUpdateRunMessageHistoryType0Item] | None | Unset):
        input_values (None | RunUpdateInputValuesType0 | Unset):
        usage_metadata (None | RunUpdateUsageMetadataType0 | Unset):
        started_at (datetime.datetime | None | Unset):
        ended_at (datetime.datetime | None | Unset):
        release_session_after (bool | None | Unset):
    """

    status: None | RunStatus | Unset = UNSET
    error: list[str] | None | Unset = UNSET
    output_data: None | RunUpdateOutputDataType0 | Unset = UNSET
    output_attachment_ids: list[str] | None | Unset = UNSET
    run_message_history: list[RunUpdateRunMessageHistoryType0Item] | None | Unset = UNSET
    input_values: None | RunUpdateInputValuesType0 | Unset = UNSET
    usage_metadata: None | RunUpdateUsageMetadataType0 | Unset = UNSET
    started_at: datetime.datetime | None | Unset = UNSET
    ended_at: datetime.datetime | None | Unset = UNSET
    release_session_after: bool | None | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        from ..models.run_update_input_values_type_0 import RunUpdateInputValuesType0
        from ..models.run_update_output_data_type_0 import RunUpdateOutputDataType0
        from ..models.run_update_usage_metadata_type_0 import RunUpdateUsageMetadataType0

        status: None | str | Unset
        if isinstance(self.status, Unset):
            status = UNSET
        elif isinstance(self.status, RunStatus):
            status = self.status.value
        else:
            status = self.status

        error: list[str] | None | Unset
        if isinstance(self.error, Unset):
            error = UNSET
        elif isinstance(self.error, list):
            error = self.error

        else:
            error = self.error

        output_data: dict[str, Any] | None | Unset
        if isinstance(self.output_data, Unset):
            output_data = UNSET
        elif isinstance(self.output_data, RunUpdateOutputDataType0):
            output_data = self.output_data.to_dict()
        else:
            output_data = self.output_data

        output_attachment_ids: list[str] | None | Unset
        if isinstance(self.output_attachment_ids, Unset):
            output_attachment_ids = UNSET
        elif isinstance(self.output_attachment_ids, list):
            output_attachment_ids = self.output_attachment_ids

        else:
            output_attachment_ids = self.output_attachment_ids

        run_message_history: list[dict[str, Any]] | None | Unset
        if isinstance(self.run_message_history, Unset):
            run_message_history = UNSET
        elif isinstance(self.run_message_history, list):
            run_message_history = []
            for run_message_history_type_0_item_data in self.run_message_history:
                run_message_history_type_0_item = run_message_history_type_0_item_data.to_dict()
                run_message_history.append(run_message_history_type_0_item)

        else:
            run_message_history = self.run_message_history

        input_values: dict[str, Any] | None | Unset
        if isinstance(self.input_values, Unset):
            input_values = UNSET
        elif isinstance(self.input_values, RunUpdateInputValuesType0):
            input_values = self.input_values.to_dict()
        else:
            input_values = self.input_values

        usage_metadata: dict[str, Any] | None | Unset
        if isinstance(self.usage_metadata, Unset):
            usage_metadata = UNSET
        elif isinstance(self.usage_metadata, RunUpdateUsageMetadataType0):
            usage_metadata = self.usage_metadata.to_dict()
        else:
            usage_metadata = self.usage_metadata

        started_at: None | str | Unset
        if isinstance(self.started_at, Unset):
            started_at = UNSET
        elif isinstance(self.started_at, datetime.datetime):
            started_at = self.started_at.isoformat()
        else:
            started_at = self.started_at

        ended_at: None | str | Unset
        if isinstance(self.ended_at, Unset):
            ended_at = UNSET
        elif isinstance(self.ended_at, datetime.datetime):
            ended_at = self.ended_at.isoformat()
        else:
            ended_at = self.ended_at

        release_session_after: bool | None | Unset
        if isinstance(self.release_session_after, Unset):
            release_session_after = UNSET
        else:
            release_session_after = self.release_session_after

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if status is not UNSET:
            field_dict["status"] = status
        if error is not UNSET:
            field_dict["error"] = error
        if output_data is not UNSET:
            field_dict["output_data"] = output_data
        if output_attachment_ids is not UNSET:
            field_dict["output_attachment_ids"] = output_attachment_ids
        if run_message_history is not UNSET:
            field_dict["run_message_history"] = run_message_history
        if input_values is not UNSET:
            field_dict["input_values"] = input_values
        if usage_metadata is not UNSET:
            field_dict["usage_metadata"] = usage_metadata
        if started_at is not UNSET:
            field_dict["started_at"] = started_at
        if ended_at is not UNSET:
            field_dict["ended_at"] = ended_at
        if release_session_after is not UNSET:
            field_dict["release_session_after"] = release_session_after

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.run_update_input_values_type_0 import RunUpdateInputValuesType0
        from ..models.run_update_output_data_type_0 import RunUpdateOutputDataType0
        from ..models.run_update_run_message_history_type_0_item import RunUpdateRunMessageHistoryType0Item
        from ..models.run_update_usage_metadata_type_0 import RunUpdateUsageMetadataType0

        d = dict(src_dict)

        def _parse_status(data: object) -> None | RunStatus | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                status_type_0 = RunStatus(data)

                return status_type_0
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            return cast(None | RunStatus | Unset, data)

        status = _parse_status(d.pop("status", UNSET))

        def _parse_error(data: object) -> list[str] | None | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                error_type_0 = cast(list[str], data)

                return error_type_0
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            return cast(list[str] | None | Unset, data)

        error = _parse_error(d.pop("error", UNSET))

        def _parse_output_data(data: object) -> None | RunUpdateOutputDataType0 | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                output_data_type_0 = RunUpdateOutputDataType0.from_dict(data)

                return output_data_type_0
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            return cast(None | RunUpdateOutputDataType0 | Unset, data)

        output_data = _parse_output_data(d.pop("output_data", UNSET))

        def _parse_output_attachment_ids(data: object) -> list[str] | None | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                output_attachment_ids_type_0 = cast(list[str], data)

                return output_attachment_ids_type_0
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            return cast(list[str] | None | Unset, data)

        output_attachment_ids = _parse_output_attachment_ids(d.pop("output_attachment_ids", UNSET))

        def _parse_run_message_history(data: object) -> list[RunUpdateRunMessageHistoryType0Item] | None | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, list):
                    raise TypeError()
                run_message_history_type_0 = []
                _run_message_history_type_0 = data
                for run_message_history_type_0_item_data in _run_message_history_type_0:
                    run_message_history_type_0_item = RunUpdateRunMessageHistoryType0Item.from_dict(
                        run_message_history_type_0_item_data
                    )

                    run_message_history_type_0.append(run_message_history_type_0_item)

                return run_message_history_type_0
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            return cast(list[RunUpdateRunMessageHistoryType0Item] | None | Unset, data)

        run_message_history = _parse_run_message_history(d.pop("run_message_history", UNSET))

        def _parse_input_values(data: object) -> None | RunUpdateInputValuesType0 | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                input_values_type_0 = RunUpdateInputValuesType0.from_dict(data)

                return input_values_type_0
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            return cast(None | RunUpdateInputValuesType0 | Unset, data)

        input_values = _parse_input_values(d.pop("input_values", UNSET))

        def _parse_usage_metadata(data: object) -> None | RunUpdateUsageMetadataType0 | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                usage_metadata_type_0 = RunUpdateUsageMetadataType0.from_dict(data)

                return usage_metadata_type_0
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            return cast(None | RunUpdateUsageMetadataType0 | Unset, data)

        usage_metadata = _parse_usage_metadata(d.pop("usage_metadata", UNSET))

        def _parse_started_at(data: object) -> datetime.datetime | None | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                started_at_type_0 = isoparse(data)

                return started_at_type_0
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            return cast(datetime.datetime | None | Unset, data)

        started_at = _parse_started_at(d.pop("started_at", UNSET))

        def _parse_ended_at(data: object) -> datetime.datetime | None | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                ended_at_type_0 = isoparse(data)

                return ended_at_type_0
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            return cast(datetime.datetime | None | Unset, data)

        ended_at = _parse_ended_at(d.pop("ended_at", UNSET))

        def _parse_release_session_after(data: object) -> bool | None | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(bool | None | Unset, data)

        release_session_after = _parse_release_session_after(d.pop("release_session_after", UNSET))

        run_update = cls(
            status=status,
            error=error,
            output_data=output_data,
            output_attachment_ids=output_attachment_ids,
            run_message_history=run_message_history,
            input_values=input_values,
            usage_metadata=usage_metadata,
            started_at=started_at,
            ended_at=ended_at,
            release_session_after=release_session_after,
        )

        run_update.additional_properties = d
        return run_update

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

import datetime
from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar, cast
from uuid import UUID

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..models.machine_status import MachineStatus
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.machine_update_machine_parameters_type_0 import MachineUpdateMachineParametersType0
    from ..models.machine_update_machine_sensitive_parameters_type_0 import MachineUpdateMachineSensitiveParametersType0


T = TypeVar("T", bound="MachineUpdate")


@_attrs_define
class MachineUpdate:
    """Schema for updating a machine

    Attributes:
        name (None | str | Unset):
        version (None | str | Unset):
        hostname (None | str | Unset):
        os_info (None | str | Unset):
        status (MachineStatus | None | Unset):
        is_available (bool | None | Unset):
        last_seen (datetime.datetime | None | Unset):
        reserved_session_id (None | Unset | UUID): Set to null to clear reservation; server will cancel any
            scheduling/running run on this machine, clear reservation, mark machine available, and trigger matching
        machine_parameters (MachineUpdateMachineParametersType0 | None | Unset): Machine-specific input values. Provide
            empty dict {} to clear all.
        machine_sensitive_parameters (MachineUpdateMachineSensitiveParametersType0 | None | Unset): Machine-specific
            sensitive input values (will be stored in Basis Theory). Provide empty dict {} to clear all.
    """

    name: None | str | Unset = UNSET
    version: None | str | Unset = UNSET
    hostname: None | str | Unset = UNSET
    os_info: None | str | Unset = UNSET
    status: MachineStatus | None | Unset = UNSET
    is_available: bool | None | Unset = UNSET
    last_seen: datetime.datetime | None | Unset = UNSET
    reserved_session_id: None | Unset | UUID = UNSET
    machine_parameters: MachineUpdateMachineParametersType0 | None | Unset = UNSET
    machine_sensitive_parameters: MachineUpdateMachineSensitiveParametersType0 | None | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        from ..models.machine_update_machine_parameters_type_0 import MachineUpdateMachineParametersType0
        from ..models.machine_update_machine_sensitive_parameters_type_0 import (
            MachineUpdateMachineSensitiveParametersType0,
        )

        name: None | str | Unset
        if isinstance(self.name, Unset):
            name = UNSET
        else:
            name = self.name

        version: None | str | Unset
        if isinstance(self.version, Unset):
            version = UNSET
        else:
            version = self.version

        hostname: None | str | Unset
        if isinstance(self.hostname, Unset):
            hostname = UNSET
        else:
            hostname = self.hostname

        os_info: None | str | Unset
        if isinstance(self.os_info, Unset):
            os_info = UNSET
        else:
            os_info = self.os_info

        status: None | str | Unset
        if isinstance(self.status, Unset):
            status = UNSET
        elif isinstance(self.status, MachineStatus):
            status = self.status.value
        else:
            status = self.status

        is_available: bool | None | Unset
        if isinstance(self.is_available, Unset):
            is_available = UNSET
        else:
            is_available = self.is_available

        last_seen: None | str | Unset
        if isinstance(self.last_seen, Unset):
            last_seen = UNSET
        elif isinstance(self.last_seen, datetime.datetime):
            last_seen = self.last_seen.isoformat()
        else:
            last_seen = self.last_seen

        reserved_session_id: None | str | Unset
        if isinstance(self.reserved_session_id, Unset):
            reserved_session_id = UNSET
        elif isinstance(self.reserved_session_id, UUID):
            reserved_session_id = str(self.reserved_session_id)
        else:
            reserved_session_id = self.reserved_session_id

        machine_parameters: dict[str, Any] | None | Unset
        if isinstance(self.machine_parameters, Unset):
            machine_parameters = UNSET
        elif isinstance(self.machine_parameters, MachineUpdateMachineParametersType0):
            machine_parameters = self.machine_parameters.to_dict()
        else:
            machine_parameters = self.machine_parameters

        machine_sensitive_parameters: dict[str, Any] | None | Unset
        if isinstance(self.machine_sensitive_parameters, Unset):
            machine_sensitive_parameters = UNSET
        elif isinstance(self.machine_sensitive_parameters, MachineUpdateMachineSensitiveParametersType0):
            machine_sensitive_parameters = self.machine_sensitive_parameters.to_dict()
        else:
            machine_sensitive_parameters = self.machine_sensitive_parameters

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if name is not UNSET:
            field_dict["name"] = name
        if version is not UNSET:
            field_dict["version"] = version
        if hostname is not UNSET:
            field_dict["hostname"] = hostname
        if os_info is not UNSET:
            field_dict["os_info"] = os_info
        if status is not UNSET:
            field_dict["status"] = status
        if is_available is not UNSET:
            field_dict["is_available"] = is_available
        if last_seen is not UNSET:
            field_dict["last_seen"] = last_seen
        if reserved_session_id is not UNSET:
            field_dict["reserved_session_id"] = reserved_session_id
        if machine_parameters is not UNSET:
            field_dict["machine_parameters"] = machine_parameters
        if machine_sensitive_parameters is not UNSET:
            field_dict["machine_sensitive_parameters"] = machine_sensitive_parameters

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.machine_update_machine_parameters_type_0 import MachineUpdateMachineParametersType0
        from ..models.machine_update_machine_sensitive_parameters_type_0 import (
            MachineUpdateMachineSensitiveParametersType0,
        )

        d = dict(src_dict)

        def _parse_name(data: object) -> None | str | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(None | str | Unset, data)

        name = _parse_name(d.pop("name", UNSET))

        def _parse_version(data: object) -> None | str | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(None | str | Unset, data)

        version = _parse_version(d.pop("version", UNSET))

        def _parse_hostname(data: object) -> None | str | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(None | str | Unset, data)

        hostname = _parse_hostname(d.pop("hostname", UNSET))

        def _parse_os_info(data: object) -> None | str | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(None | str | Unset, data)

        os_info = _parse_os_info(d.pop("os_info", UNSET))

        def _parse_status(data: object) -> MachineStatus | None | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                status_type_0 = MachineStatus(data)

                return status_type_0
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            return cast(MachineStatus | None | Unset, data)

        status = _parse_status(d.pop("status", UNSET))

        def _parse_is_available(data: object) -> bool | None | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(bool | None | Unset, data)

        is_available = _parse_is_available(d.pop("is_available", UNSET))

        def _parse_last_seen(data: object) -> datetime.datetime | None | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                last_seen_type_0 = isoparse(data)

                return last_seen_type_0
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            return cast(datetime.datetime | None | Unset, data)

        last_seen = _parse_last_seen(d.pop("last_seen", UNSET))

        def _parse_reserved_session_id(data: object) -> None | Unset | UUID:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                reserved_session_id_type_0 = UUID(data)

                return reserved_session_id_type_0
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            return cast(None | Unset | UUID, data)

        reserved_session_id = _parse_reserved_session_id(d.pop("reserved_session_id", UNSET))

        def _parse_machine_parameters(data: object) -> MachineUpdateMachineParametersType0 | None | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                machine_parameters_type_0 = MachineUpdateMachineParametersType0.from_dict(data)

                return machine_parameters_type_0
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            return cast(MachineUpdateMachineParametersType0 | None | Unset, data)

        machine_parameters = _parse_machine_parameters(d.pop("machine_parameters", UNSET))

        def _parse_machine_sensitive_parameters(
            data: object,
        ) -> MachineUpdateMachineSensitiveParametersType0 | None | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                machine_sensitive_parameters_type_0 = MachineUpdateMachineSensitiveParametersType0.from_dict(data)

                return machine_sensitive_parameters_type_0
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            return cast(MachineUpdateMachineSensitiveParametersType0 | None | Unset, data)

        machine_sensitive_parameters = _parse_machine_sensitive_parameters(d.pop("machine_sensitive_parameters", UNSET))

        machine_update = cls(
            name=name,
            version=version,
            hostname=hostname,
            os_info=os_info,
            status=status,
            is_available=is_available,
            last_seen=last_seen,
            reserved_session_id=reserved_session_id,
            machine_parameters=machine_parameters,
            machine_sensitive_parameters=machine_sensitive_parameters,
        )

        machine_update.additional_properties = d
        return machine_update

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="MouseDragRequest")


@_attrs_define
class MouseDragRequest:
    """
    Attributes:
        to_x (int):
        to_y (int):
        start_x (int):
        start_y (int):
        duration (float | None | Unset):
        button (None | str | Unset): 'left' | 'right' | 'middle' Default: 'left'.
    """

    to_x: int
    to_y: int
    start_x: int
    start_y: int
    duration: float | None | Unset = UNSET
    button: None | str | Unset = "left"
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        to_x = self.to_x

        to_y = self.to_y

        start_x = self.start_x

        start_y = self.start_y

        duration: float | None | Unset
        if isinstance(self.duration, Unset):
            duration = UNSET
        else:
            duration = self.duration

        button: None | str | Unset
        if isinstance(self.button, Unset):
            button = UNSET
        else:
            button = self.button

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "to_x": to_x,
                "to_y": to_y,
                "start_x": start_x,
                "start_y": start_y,
            }
        )
        if duration is not UNSET:
            field_dict["duration"] = duration
        if button is not UNSET:
            field_dict["button"] = button

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        to_x = d.pop("to_x")

        to_y = d.pop("to_y")

        start_x = d.pop("start_x")

        start_y = d.pop("start_y")

        def _parse_duration(data: object) -> float | None | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(float | None | Unset, data)

        duration = _parse_duration(d.pop("duration", UNSET))

        def _parse_button(data: object) -> None | str | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(None | str | Unset, data)

        button = _parse_button(d.pop("button", UNSET))

        mouse_drag_request = cls(
            to_x=to_x,
            to_y=to_y,
            start_x=start_x,
            start_y=start_y,
            duration=duration,
            button=button,
        )

        mouse_drag_request.additional_properties = d
        return mouse_drag_request

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="MouseClickRequest")


@_attrs_define
class MouseClickRequest:
    """
    Attributes:
        x (int | None | Unset):
        y (int | None | Unset):
        button (str | Unset):  Default: 'left'.
        down (bool | None | Unset): None = full click, True = mouse down, False = mouse up
        clicks (int | Unset): Number of clicks (1=single, 2=double, 3=triple) Default: 1.
    """

    x: int | None | Unset = UNSET
    y: int | None | Unset = UNSET
    button: str | Unset = "left"
    down: bool | None | Unset = UNSET
    clicks: int | Unset = 1
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        x: int | None | Unset
        if isinstance(self.x, Unset):
            x = UNSET
        else:
            x = self.x

        y: int | None | Unset
        if isinstance(self.y, Unset):
            y = UNSET
        else:
            y = self.y

        button = self.button

        down: bool | None | Unset
        if isinstance(self.down, Unset):
            down = UNSET
        else:
            down = self.down

        clicks = self.clicks

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if x is not UNSET:
            field_dict["x"] = x
        if y is not UNSET:
            field_dict["y"] = y
        if button is not UNSET:
            field_dict["button"] = button
        if down is not UNSET:
            field_dict["down"] = down
        if clicks is not UNSET:
            field_dict["clicks"] = clicks

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)

        def _parse_x(data: object) -> int | None | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(int | None | Unset, data)

        x = _parse_x(d.pop("x", UNSET))

        def _parse_y(data: object) -> int | None | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(int | None | Unset, data)

        y = _parse_y(d.pop("y", UNSET))

        button = d.pop("button", UNSET)

        def _parse_down(data: object) -> bool | None | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(bool | None | Unset, data)

        down = _parse_down(d.pop("down", UNSET))

        clicks = d.pop("clicks", UNSET)

        mouse_click_request = cls(
            x=x,
            y=y,
            button=button,
            down=down,
            clicks=clicks,
        )

        mouse_click_request.additional_properties = d
        return mouse_click_request

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

import datetime
from collections.abc import Mapping
from typing import Any, TypeVar, cast
from uuid import UUID

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..types import UNSET, Unset

T = TypeVar("T", bound="PoolResponse")


@_attrs_define
class PoolResponse:
    """Pool response schema

    Attributes:
        name (str):
        id (UUID):
        organization_id (str):
        created_at (datetime.datetime):
        updated_at (datetime.datetime):
        description (None | str | Unset):
        machine_count (int | None | Unset): Number of machines in this pool Default: 0.
    """

    name: str
    id: UUID
    organization_id: str
    created_at: datetime.datetime
    updated_at: datetime.datetime
    description: None | str | Unset = UNSET
    machine_count: int | None | Unset = 0
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        name = self.name

        id = str(self.id)

        organization_id = self.organization_id

        created_at = self.created_at.isoformat()

        updated_at = self.updated_at.isoformat()

        description: None | str | Unset
        if isinstance(self.description, Unset):
            description = UNSET
        else:
            description = self.description

        machine_count: int | None | Unset
        if isinstance(self.machine_count, Unset):
            machine_count = UNSET
        else:
            machine_count = self.machine_count

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "name": name,
                "id": id,
                "organization_id": organization_id,
                "created_at": created_at,
                "updated_at": updated_at,
            }
        )
        if description is not UNSET:
            field_dict["description"] = description
        if machine_count is not UNSET:
            field_dict["machine_count"] = machine_count

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        name = d.pop("name")

        id = UUID(d.pop("id"))

        organization_id = d.pop("organization_id")

        created_at = isoparse(d.pop("created_at"))

        updated_at = isoparse(d.pop("updated_at"))

        def _parse_description(data: object) -> None | str | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(None | str | Unset, data)

        description = _parse_description(d.pop("description", UNSET))

        def _parse_machine_count(data: object) -> int | None | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(int | None | Unset, data)

        machine_count = _parse_machine_count(d.pop("machine_count", UNSET))

        pool_response = cls(
            name=name,
            id=id,
            organization_id=organization_id,
            created_at=created_at,
            updated_at=updated_at,
            description=description,
            machine_count=machine_count,
        )

        pool_response.additional_properties = d
        return pool_response

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

import datetime
from collections.abc import Mapping
from typing import Any, TypeVar, cast
from uuid import UUID

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..models.connection_status import ConnectionStatus
from ..types import UNSET, Unset

T = TypeVar("T", bound="ConnectionResponse")


@_attrs_define
class ConnectionResponse:
    """Connection response schema

    Attributes:
        websocket_id (str):
        id (UUID):
        machine_id (UUID):
        connected_at (datetime.datetime):
        disconnected_at (datetime.datetime | None):
        last_ping (datetime.datetime):
        status (ConnectionStatus):
        ip_address (None | str | Unset):
        user_agent (None | str | Unset):
    """

    websocket_id: str
    id: UUID
    machine_id: UUID
    connected_at: datetime.datetime
    disconnected_at: datetime.datetime | None
    last_ping: datetime.datetime
    status: ConnectionStatus
    ip_address: None | str | Unset = UNSET
    user_agent: None | str | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        websocket_id = self.websocket_id

        id = str(self.id)

        machine_id = str(self.machine_id)

        connected_at = self.connected_at.isoformat()

        disconnected_at: None | str
        if isinstance(self.disconnected_at, datetime.datetime):
            disconnected_at = self.disconnected_at.isoformat()
        else:
            disconnected_at = self.disconnected_at

        last_ping = self.last_ping.isoformat()

        status = self.status.value

        ip_address: None | str | Unset
        if isinstance(self.ip_address, Unset):
            ip_address = UNSET
        else:
            ip_address = self.ip_address

        user_agent: None | str | Unset
        if isinstance(self.user_agent, Unset):
            user_agent = UNSET
        else:
            user_agent = self.user_agent

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "websocket_id": websocket_id,
                "id": id,
                "machine_id": machine_id,
                "connected_at": connected_at,
                "disconnected_at": disconnected_at,
                "last_ping": last_ping,
                "status": status,
            }
        )
        if ip_address is not UNSET:
            field_dict["ip_address"] = ip_address
        if user_agent is not UNSET:
            field_dict["user_agent"] = user_agent

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        websocket_id = d.pop("websocket_id")

        id = UUID(d.pop("id"))

        machine_id = UUID(d.pop("machine_id"))

        connected_at = isoparse(d.pop("connected_at"))

        def _parse_disconnected_at(data: object) -> datetime.datetime | None:
            if data is None:
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                disconnected_at_type_0 = isoparse(data)

                return disconnected_at_type_0
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            return cast(datetime.datetime | None, data)

        disconnected_at = _parse_disconnected_at(d.pop("disconnected_at"))

        last_ping = isoparse(d.pop("last_ping"))

        status = ConnectionStatus(d.pop("status"))

        def _parse_ip_address(data: object) -> None | str | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(None | str | Unset, data)

        ip_address = _parse_ip_address(d.pop("ip_address", UNSET))

        def _parse_user_agent(data: object) -> None | str | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(None | str | Unset, data)

        user_agent = _parse_user_agent(d.pop("user_agent", UNSET))

        connection_response = cls(
            websocket_id=websocket_id,
            id=id,
            machine_id=machine_id,
            connected_at=connected_at,
            disconnected_at=disconnected_at,
            last_ping=last_ping,
            status=status,
            ip_address=ip_address,
            user_agent=user_agent,
        )

        connection_response.additional_properties = d
        return connection_response

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

import datetime
from collections.abc import Mapping
from typing import Any, TypeVar, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..types import UNSET, Unset

T = TypeVar("T", bound="WorkflowPromptImageListItem")


@_attrs_define
class WorkflowPromptImageListItem:
    """Schema for an item in the workflow prompt images list

    Attributes:
        supabase_url (str): The stable supabase:// URL to use in workflow prompt HTML
        path (str): The storage path of the image
        filename (str): The filename of the image
        created_at (datetime.datetime | None | Unset): When the image was uploaded
        size_bytes (int | None | Unset): The size of the file in bytes
    """

    supabase_url: str
    path: str
    filename: str
    created_at: datetime.datetime | None | Unset = UNSET
    size_bytes: int | None | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        supabase_url = self.supabase_url

        path = self.path

        filename = self.filename

        created_at: None | str | Unset
        if isinstance(self.created_at, Unset):
            created_at = UNSET
        elif isinstance(self.created_at, datetime.datetime):
            created_at = self.created_at.isoformat()
        else:
            created_at = self.created_at

        size_bytes: int | None | Unset
        if isinstance(self.size_bytes, Unset):
            size_bytes = UNSET
        else:
            size_bytes = self.size_bytes

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "supabase_url": supabase_url,
                "path": path,
                "filename": filename,
            }
        )
        if created_at is not UNSET:
            field_dict["created_at"] = created_at
        if size_bytes is not UNSET:
            field_dict["size_bytes"] = size_bytes

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        supabase_url = d.pop("supabase_url")

        path = d.pop("path")

        filename = d.pop("filename")

        def _parse_created_at(data: object) -> datetime.datetime | None | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                created_at_type_0 = isoparse(data)

                return created_at_type_0
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            return cast(datetime.datetime | None | Unset, data)

        created_at = _parse_created_at(d.pop("created_at", UNSET))

        def _parse_size_bytes(data: object) -> int | None | Unset:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(int | None | Unset, data)

        size_bytes = _parse_size_bytes(d.pop("size_bytes", UNSET))

        workflow_prompt_image_list_item = cls(
            supabase_url=supabase_url,
            path=path,
            filename=filename,
            created_at=created_at,
            size_bytes=size_bytes,
        )

        workflow_prompt_image_list_item.additional_properties = d
        return workflow_prompt_image_list_item

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
